from rv import commands, extra_commands, rvtypes
from rv.commands import NeutralMenuState
from PySide2 import QtCore
import os


# This can be split out in a separate config file
# that you can store in RV_SUPPORT_PATH to add
# project-level customization.
EXCLUDE_EXTENSIONS = [".txt", ".DS_Store"]

def groupMemberOfType(node, memberType):
    for n in commands.nodesInGroup(node):
        if commands.nodeType(n) == memberType:
            return n
    return None

class Example_Package_UnloadExcludedExtensionsMode(rvtypes.MinorMode):

    def __init__(self):
        rvtypes.MinorMode.__init__(self)

        globalBindings = [
            ("source-group-complete", self.newSource, "New Source"),
        ]
        localBindings = None

        menu = None

        self.init("Example_Package_UnloadExcludedExtensions", globalBindings, localBindings, menu, 'zz_source_setup', 0)

    def filterSourcePaths(self, sourcePaths):
        # Do your own logic for filtering source paths.
        new_paths = []
        for i in sourcePaths:
            path_name, ext = os.path.splitext(i)
            if not ext:
                continue
            if ext in EXCLUDE_EXTENSIONS:
                continue
            new_paths.append(i)
        return new_paths


    def newSource(self, event):
        try:
            args         = event.contents().split(";;")
            group        = args[0]
            fileSource   = groupMemberOfType(group, "RVFileSource")
            if fileSource:
                mmp = "%s.media.movie" % fileSource
                sourcePaths = commands.getStringProperty(mmp)
                filteredSourcePaths = self.filterSourcePaths(sourcePaths)
                if not filteredSourcePaths:

                    def deleteFileSource():
                        (_,outputs) = commands.nodeConnections(group)

                        # Remove all dependencies.  See session manager for similar behavior.
                        for output in outputs:
                            (inputs, _) = commands.nodeConnections(output)
                            commands.setNodeInputs(output, [i for i in inputs if i != group])

                        commands.deleteNode(group)

                    # Delay this until after the event completes.
                    self._deleteTimer = QtCore.QTimer.singleShot(0, deleteFileSource)
                else:
                    # If we have removed media paths from our source, then re-set the source path to remove the garbage.
                    # This allows garbage to be removed from second eyes or when trying to add audio.
                    if sourcePaths != filteredSourcePaths:
                        commands.setStringProperty(mmp, filteredSourcePaths, True)

                    # Ignore the event if the source isn't deleted, otherwise absorb it to prevent further processing.
                    event.reject()
        except Exception as e:
            print e
            event.reject()      
            
def createMode():
    return Example_Package_UnloadExcludedExtensionsMode()
